@@ -7,7 +7,7 @@
 #ifndef KPUBLICTRANSPORT_GEOJSON_P_H
 #define KPUBLICTRANSPORT_GEOJSON_P_H
 
-#include "kpublictransport_export.h"
+#include <vector>
 
 class QJsonObject;
 class QPointF;
@@ -15,22 +15,29 @@ class QPolygonF;
 
 namespace KPublicTransport {
 
-/** GeoJSON utilities.
- *  @internal only exported for unit tests
- */
+/** GeoJSON utilities. */
 namespace GeoJson
 {
     /** Coordinate of a point geometry object. */
-    KPUBLICTRANSPORT_EXPORT QPointF readPoint(const QJsonObject &obj);
+    QPointF readPoint(const QJsonObject &obj);
 
     /** Reads a line string object. */
     QPolygonF readLineString(const QJsonObject &obj);
 
-    /** Outer path of a polygon or multi-polygon geometry object. */
+    /** Outer path of a polygon or multi-polygon geometry object.
+     *  Multiple outer polygons are united.
+     */
     QPolygonF readOuterPolygon(const QJsonObject &obj);
+    /** Outer paths of a polygon or multi-polygon geometry object. */
+    std::vector<QPolygonF> readOuterPolygons(const QJsonObject &obj);
 
     /** Creates a line string object. */
     QJsonObject writeLineString(const QPolygonF &lineString);
+
+    /** Create a polygon object. */
+    QJsonObject writePolygon(const QPolygonF &polygon);
+    /** Create a multi-polygon object. */
+    QJsonObject writePolygons(const std::vector<QPolygonF> &polygons);
 }
 
 }
